<cfscript>
 /**
 * Copyright (C) 2013 Ortus Solutions, Corp
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */

    /**
     * Returns the instance of the Ortus Redis Cache provider that corresponds with a cache defined in the Lucee admin.  Pass in the name of a cache, or it will default to the object cache.
     * 
     * @cacheName The name of the registered cache connection to get a native Jedis client from
     * 
     * @return redis.clients.jedis.Jedis
     */
    any function redisGetProvider( string cacheName='' ){
		var cacheUtil = createObject( 'java', 'lucee.runtime.cache.CacheUtil' );
		var pc        = getPageContext();
		var config    = pc.getConfig();

		// If no cache name, grab the `default` object cache.  
		// Error will be thrown if the default object cache is not Redis.
		if( !len( arguments.cacheName ) ){
			var oCache = cacheUtil.getDefault( pc, config.CACHE_TYPE_OBJECT );				
		} else {
			// Retrieve the named cache instance
			var oCache = cacheUtil.getCache( pc, arguments.cacheName );
		}

		// Verify the cache is a Redis cache. Not using instanceof due to weird behavior when jars conflicted.
		var cacheClassName = oCache.getClass().getName();
		if( cacheClassName != "ortus.extension.cache.redis.RedisCache" ){
			throw ( "Cache [" & arguments.cacheName & "] does not use the Ortus Redis provider.  Instead it is using " & cacheClassName );
		}
		
		return oCache;
	}
</cfscript>